Windows Sicherung/Wiederherstellung mit (wimlib/robocopy) ln.exe

mchawk777 schrieb:
Lenk nicht vim Thema ab, wenn es argumentativ dünn wird.
Häh? Also von mir aus hab ich mich im vorherigen Posting nicht deutlich genug ausgedrückt. Aber das Du jetzt sogar besser als ich selber wissen willst, was ich gemeint habe und was nicht, ist vollkommen Banane.

mchawk777 schrieb:
Ich sprach davon und Du hast im Kontext nachgefragt.
Lies mal bitte die betreffenden Postings noch mal nach.
Spannenderweise hat xerex das ja offenbar ganz anders (nämlich in meinem Sinne) verstanden und dementsprechend war ja dann auch seine Antwort.
Wie gesagt: Ich würde sogar einräumen (und das hab ich ja auch schon), das ich mich unklar ausgedrückt hab.
Da hätte man auch einfach sagen können "Ja gut. War wohl offenbar ein Missverständnis" und gut ist.
Aber da gleich ein Drama drum zu machen

mchawk777 schrieb:
Linux ist für Dich kein Werkzeug sondern eine Weltanschauung, deren Schwächen man zu ignorieren und keinesfalls zu kritisieren hat.
Häh? Du liest wirklich nicht meine Postings.
Ich habe ja sogar eingeräumt, das das adressierte Problem ein Problem ist und sogar lange Erklärungen hinzugefügt damit es nachvollziehbar ist und diesmal keine Missverständnisse entstehen.

Du ziehst Dir da irgendwas aus dem Hintern und gehst nicht auf die Punkte ein.
Stattdessen wetterst Du über die doofe Linuxcommunity und ihr Mimimi.
Da stellt sich die Frage, wer hier wohl die Idiologiebrille auf hat.

Man darf selbstverständlich Dinge kritisieren. Aber mit Pauschalisierungen ("die Community") umsich zu werfen hat halt mit Kritik nichts zu tun.

Versteh mich nicht falsch. Natürlich darf man auch mal Meinung raushauen. Von mir aus auch undifferenziert. Aber wenn Postings zum Großteil aus solcher Meinung statt technischer Diskussion besteht und sich dann gleichzeitig über Weltanschauung beschwert wird, dann ist das doch schon arg widersprüchlich.
 
  • Gefällt mir
Reaktionen: nutrix
andy_m4 schrieb:
Ja. Deswegen sagte ich ja, das man dort einfach die Anwendung terminiert und anschließend wieder neu startet.
Und jetzt kann man sagen: "Ist ja voll doof. Dann ist meine Anwendung ja kurzzeitig nicht verfügbar."
In der Praxis ist das aber oft kein Problem.
Privat stimmt das, geschäftlich wird sowas zum Problem. Je mehr Daten du hast und je länger damit die Sicherung dauert, desto weniger wird das zur Option. Stündliche Snapshots? Kannst du gleich vergessen, die musst du dann auf Applikationsebene für jede Applikation einzeln machen, das schränkt einen schon ein.

Unter Umständen geht es dann weiter bis auf die Storage Ebene, eine Linux Appliance per Snapshot sichern? Kannst du bei den meisten schlichtweg vergessen. Da hat sich Microsoft mit den VSS Writern eine praktische Lösung ausgedacht, auch wenn sie zumindest in den Anfangszeiten durchaus fehleranfällig war.

Aber wir driften ab und vom OP kommt nichts mehr.
 
  • Gefällt mir
Reaktionen: mchawk777
xexex schrieb:
Privat stimmt das, geschäftlich wird sowas zum Problem.
Ja. Ich bin da auch durchaus bei Dir.

xexex schrieb:
Je mehr Daten du hast und je länger damit die Sicherung dauert, desto weniger wird das zur Option.
Das stimmt.
Wie gesagt: Ich will diesen Aspekt auch gar nicht wegwischen oder so.
Es kommt eben aufs Szenario an.

Ich wollte lediglich einem pauschalen Aussage a-la "Weils das nicht gibt, ist es ein riesen Problem" entgegentreten und da versuchen differenziert drauf zu gucken.

Insbesondere ja auch, weil es hier auch um privaten Szenarien ging. Und da hat man ja üblicherweise keine Terrabyte-großen Datenbanken.
Und selbst dann kann man sich behelfen.
Also ich greife einfach mal rsync auf, da es hier schon genannt wurde:
Man ruft das auf und kopiert die Datenbank-Dateien weg.
Dann beendet man die Datenbank und macht einen zweiten rsync-Durchlauf, welches dann nur noch das Delta kopieren muss.
Dann hat man zwar immer noch 'ne Downtime aber die ist deutlich kürzer.

xexex schrieb:
Da hat sich Microsoft mit den VSS Writern eine praktische Lösung ausgedacht, auch wenn sie zumindest in den Anfangszeiten durchaus fehleranfällig war.
Die ist ja auch unbestritten praktisch und es ist auch gut, das zu haben.
In vielen Szenarien kommt man aber auch zurecht, wenn man das nicht hat. Mehr wollte ich eigentlich gar nicht sagen.
 
Nochmal:

Ich möchte eine vollständige Windows-Installation so effizient sichern und wiederherstellen können, wie es sich bei Linux-Installationen bei mir und im Bekanntenkreis schon seit 10 Jahren bewährt:
Caramon2 schrieb:
Ich sichere meine vollständige Linux-Installaion mir rsync auf externen Laufwerken. Das hat den großen Vorteil, dass nach der ersten Sicherung nur noch die Änderungen übertragen werden müssen. Gleiches gilt für die Wiederherstellung (von einem Livesystem aus). - Wie kann man Windows genauso effizient sichern und wiederherstellen?
Im hier verlinkten Beitrag habe ich mit Screenshots und einem ausführlich dokumentierten Beispiel-Skript gezeigt und erklärt, wie ich das mache:
Caramon2 schrieb:
Meine Linux-Sicherung per rsync funktioniert und hat sich schon oft bewährt.
Das funktioniert schon die ganze Zeit bei allen problemlos aus dem laufenden Betrieb heraus: Snapshots (oder vergleichbares) sind dafür nicht erforderlich.

Als Dateisystem werden ext4, xfs und btrfs (aber ohne diesen @-Kram!) genutzt und es wird/wurde schon mit LinuxMint, LMDE, Solus, Zorin, Artix, Endevour, openSUSE und Manjaro erfolgreich genutzt. - M. E. ist Distributionsunabhängig:

Man starte es, wartet bis es durch ist und lässt währenddessen das System in Ruhe.

Die eigentliche Sicherung wird prizipiell so durchgeführt:
Caramon2 schrieb:
sudo rsync -vaxH --del --link-dest=(vorheriges Backup) (Quelle) (Ziel)

Der Ablauf::
Caramon2 schrieb:
Die Sicherung soll möglichst einfach funktionieren: Der Bekannte schließt im normalen Betrieb einfach das entsprechende Sicherungslaufwerk an, öffnet es und führt das dort befindliche Sicherungsskipt aus, das dann inkl. VSS alles weitere macht. - Er muss nur warten bis es fertig ist, das Sicherungslaufwerk schließen, sicher entfernen und dann abziehen.
Als Masstab dient mir der Hausmeister hier (Bj. '51 - wenn er damit klar kommt, verstehen das auch alle anderen) und obiges ist selbst für ihn kein Problem.

Mit einem der üblichen Backup-Programme brauche ich ihm nicht zu kommen (ich hatte es versucht): Das GUI ist für ihn Reizüberflutung, da traut er sich nicht ran.

Da ich ihm auch nicht zutraue, die Sicherungplatte sicher zu entfernen, bevor er sie abzieht, hatte ich das Sicherungsskript so erweitert, dass es zuletzt noch einen Moment wartet und dann den PC herunterfährt.

Jeden Sonntag, wenn er den PC nicht mehr braucht, schließt er die Sicherungplatte an, startet die Sicherung und geht mit dem Hund raus. - Wenn er zurück ist, ist die Sicherung durch, der PC aus und er kann die Platte in Ruhe abziehen und weglegen.

Wenn etwas nicht mehr funktioniert, sagt er Bescheid und ich bringe das wieder i. O. Also mit der Wiederherstellung hat er nichts zu tun. - Das letzte Mal war übrigens noch vor Corona.

Das gleiche hätte ich auch gerne für Windows: Dafür ist dieser Thread

Weil einige seiner Bekannten davon gehört haben, dass Windows von Updates "kaputt" gehen kann und er mich gefragt hat, ob ich denen nicht auch so eine Sicherung einrichten kann. - Linux wollen sie nicht.

Ursprünglich dachte ich, wimlib wäre dafür ideal, aber es hat sich dann selbst disqualifiziert:
Caramon2 schrieb:
wenn man eine alte Sicherung aus dem Wim löscht, wird das komplette Win ohne das gelöscht umkopiert und damit neu erstellt, anstatt dass das Wim sparse ist und der gelöschte Bereich einfach freigegeben wird.

Die KIs von Google und Opera meinten unabhängig voneinander, das wäre per VSS und robocopy mit ln.exe möglich (also die Sicherung aus dem laufenden System heraus) und die Wiederherstellung würde dann mit einem PE-Windows gemacht werden - z. B.:
Caramon2 schrieb:
Das Hirens PE Win wurde 2024 auf Windows 11 aktualisiert, bootet lt. FAQ aber auch problemlos auf älteren Rechnern:

https://www.hirensbootcd.org/download/

Den erste Entwurf eines Sicherungsskripts (von der Google-KI) hatte ich an #4 angehängt: Ich würde es nicht ausprobieren, sondern wollte damit nur zeigen, welche Befehle dort wie eingesetzt werden.

Das eigentliche Sicherungskript würde ich wie meine Linux-Sicherung aufbauen: s. o.
 
Caramon2 schrieb:
Das funktioniert schon die ganze Zeit bei allen problemlos aus dem laufenden Betrieb heraus: Snapshots (oder vergleichbares) sind dafür nicht erforderlich.
So funktioniert es aber unter Windows nicht und ich würde mir an dieser Stelle fragen, wie oft du wohl schon mit den gesicherten Daten eine funktionierende Linux Systemwiederherstellung durchgeführt hast.

Von daher kann ich nur meine Frage wiederholen, was möchtest du eigentlich tun? Wenn du nur Daten sichern willst brauchst du dich mit WIM gar nicht erst befassen, da reicht ein selbstgeschriebener Script oder Freeware, wie das bereits verlinkte Back4Sure.

Wenn du ein funktionierendes System wiederherstellen willst, dann nimm eine DAU taugliche Software dafür, erst recht wenn du eine KI befragen musst wie es möglicherweise mit Bordmitteln machbar wäre. Das ist nämlich durchaus machbar, dann sollte man aber schon die dafür nötige Partitionierung und diverse Windows eigene Tools kennen, damit man ein solches Image wieder startfähig macht.

Caramon2 schrieb:
Mit einem der üblichen Backup-Programme brauche ich ihm nicht zu kommen (ich hatte es versucht): Das GUI ist für ihn Reizüberflutung, da traut er sich nicht ran.
Muss er auch nicht, wobei ich mich dann frage was er mit irgendeinem Script von dem er nichts versteht anfangen soll und wie du sicherstellst das die Sicherung noch läuft. Wenn du dem Benutzer keinerlei Interaktion zutraust, soll er sich eine externe Festplatte kaufen, die ein "Back-Up Knopf" und die passende Software gleich mitbringt.

1790271150903.png

https://de.transcend-info.com/product/external-hard-drive/storejet-25a3

Fertig ist deine Sicherung für "DAUs", mit der man auch eine Systemwiederhestellung ohne ein IT Studium hinbekommt. Unter Linux ist es so, dann will ich es unter Windows so haben, funktioniert an dieser Stelle schlichtweg nicht, es sind grundverschiedene Systeme.
 
  • Gefällt mir
Reaktionen: nutrix
Armin#1992 schrieb:
Grundsätzlich klingt der Ansatz interessant. WIM/WIMLib kann durchaus inkrementelle bzw. differenzielle Images ermöglichen, aber bei einer vollständigen Windows-Systemwiederherstellung gibt es ein paar Stolpersteine – insbesondere bei Bootloader, EFI-Partition, BCD und speziellen NTFS-/Windows-Attributen.
Erst mal geht es nur darum, ein z. B. durch Updates zerschossenes Windows wieder zurückzusetzen: s. Zitate im Eröffnungsbeitrag.

Wenn das funktioniert, kann man den Rest angehen (wenn es nicht funktioniert, hat sich der Rest ja sowieso erledigt). - Allzu kompliziert kann es aber nicht sein, ein wiederhergestelltes Windows bootfähig zu bekommen: Früher hat dazu fdisk /mbr gereicht und jetzt soll man stattdessen bcdboot C:\Windows /l de-de nehmen (oder bcdboot C:\Windows /l de-de /s C:).

Ich bevorzuge den BIOS/CSM-Modus und da habe ich per ntfsclone gesicherte Windowsen schon mehrfach auf anderen Laufwerken und sogar anderen Rechnern voll funktionsfähig wiederhergestellt. - UEFI ist mir zu umständlich und fehleranfällig - z. B. wenn man auf eine USB-SSD installiert, die man an mehreren Rechnern booten können möchte: im BIOS/CSM-Modus funktioniert das sogar mit Windows 11: ich hatte den falschen Booteingang erwischt und habe jeden Moment einen BSOD erwartet, stattdessen bootet es fertig und ließ sich normal nutzen.

wimlib ist aus den genannten Gründen inzwischen aus dem Rennen, aber mit robocopy (Quelle) (Ziel) /MIR /COPYALL /DCOPY:DAT /XJ /R:2 /W:2 /MT:8 /SL (als Administrator) soll es angeblich auch möglich sein:
Code:
/MIR                Spiegelt die Quelle ins Ziel
                    - kopiert neue und geänderte Dateien
                    - löscht im Ziel Dateien, die es in der Quelle nicht mehr gibt

/COPYALL            Kopiert alle Dateiinfos:
                    - Daten
                    - Attribute
                    - Zeitstempel
                    - NTFS-Berechtigungen (ACLs)
                    - Besitzer
                    - Auditing-Infos

/DCOPY:DAT          Kopiert auch Verzeichnisinfos:
                    - Data
                    - Attributes
                    - Timestamps

/XJ                 Überspringt Junctions
                    - verhindert Schleifen und unnötige Doppelkopien

/R:2                Bei Fehlern 2 Wiederholungsversuche

/W:2                2 Sekunden Wartezeit zwischen Wiederholungen

/MT:8               Multithread-Kopieren mit 8 Threads
                    - oft deutlich schneller

/SL                 Kopiert symbolische Links als Links
                    - nicht den Zielinhalt
Entweder von einem PE-Windows aus (für die Wiederherstellung sowieso) und die Sicherung soll per Schattenkopie auch aus dem laufenden Betrieb heraus möglich sein.

Das unverändertes per Hardlinks übernommen wird, soll mit ln.exe --delorean (vorheriges Backup) (neues Backup) möglich sein.
(Ob Deloean wohl was mit Apples Time Machine zu tun hat, das auf gleiche Weise arbeitet? ;))

Also zuerst erstellt man das neue Backup als Hardlinks vom alten (was schnell ist, weil nur die Verzeichnisseinträge dupliziert werden) und das aktualisierte man dann mit robocopy:
  • neues/geändertes wird überschrieben
  • gelöschtes wird gelöscht
  • unverändertes bleiben Hardlinks
Armin#1992 schrieb:
Ich würde deshalb zwischen „Dateien effizient sichern“
Das soll nicht getrennt werden: Jede Sicherungsstufe ist die vollständige Installation. - Genau wie bei meiner verlinkten Linux-Sicherung.

Da alles als normale Dateien gesichert wird, kann man bei Bedarf auch einfach mit dem Explorer rein gehen und sich z. B. ein versehentlich gelöschtes Video (oder auch ganze Verzeichnisse) zurück kopieren.

Da diese Komplettsicheung mehrstufig durchgeführt wird, hat man so auch Zugriff auf die entsprechenden Versionsstände zum Zeitpunkt der jeweiligen Sicherung: z. B. bei einem Dokument, an dem man schon länger schreibt.

Das hatte ich gerade erst neulich gebraucht, als ich gemerkt habe, dass ich im Juli versehentlich wichtige Notizen überschieben und gespeichert hatte: Ich sichere mein System 10stufig (0-9) on demand (jedesmal, wenn sich gravierendes geändert hat) und am Monatsende (m0-m9), so dass die on demand Sicherungen aktuelle, kurzfristig Änderungen abdecken und die monatliche 10 Monate zurück reichen.

Armin#1992 schrieb:
und „ein bootfähiges Windows 1:1 wiederherstellen“ unterscheiden. Letzteres sollte man unbedingt mit einem Testsystem prüfen, bevor man sich im Ernstfall darauf verlässt.
Das sowieso, auch deshalb dieser Thread:

Mangels Key und Breitband-Internet könnte ich es nur mit einem dafür frisch und offline installierten Windows 11 22H2 testen (das ISO habe ich da und neuere sind mir zu groß), das keine Internetverbindung bekommt, also auch keine Aktualisierungen. - Das wäre nur bedingt aussagekräftige.
 
Update:
Caramon2 schrieb:
Vorab (Nachtrag vom 26.09.):

In #24 hatte ich zusammengefasst und konkretisiert, worum es hier geht:

Ich suche eine Möglichkeit, Windows weitestgehend mit Bordmitteln so einfach und effizient zu sichern, wie es sich mit meiner verlinkten Linux-Sicherung schon seit 10 Jahren bewährt. - Wichtig: Linux ist hier kein Thema! Die verlinkte Sicherung dient nur als Referenz.

Dieses sollte eigentlich ein kontruktiver Thread werden, aus dem sich eine Sicherungs-/Wiederherstellungsmöglichkeit für Windows ergibt, über die man selbst die Kontrolle hat. - Statt von anderen abhängig zu sein, die jederzeit was ändern/verschlimmbessern können (letzters ist inzwischen ja eher die Regel, als eine Ausnahme…): D. h. keine proprietäre Software.

Davon hätten alle was, die sich dafür interessieren.

Also bitte nur noch Beiträge, die auch wirklich zum Thema beitragen. ;) - "Das kenne ich nicht, will ich nicht, geht nicht" (ohne es überhaupt ausprobiert zu haben) ist nicht hilfreich.

Vielen Dank.
 
Mit der Option /L (dry run) kann man es gefahrlos testen (wichtig: das DOS-Fenster muss als Admin geöffnet werden - z. B. im Startmenü "cmd" + Strg+Umschalt+Enter).

Beim Hirens PE-Win (ist nach dem booten auf X:\) lief es problemlos durch:

RCvsWIN.png

Das "test"-Verzeichnis hatte ich vorher erstellt und bei einem "echten" Durchlauf hätte ich natürlich auf einem anderen Laufwerk gesichert.



Hier schon mal das Tools für die Hardlinks: Ln - Command line Hardlinks (ich empfehle eine der statischen Versionen)
The NTFS filesystem supports a lot of features like Hardlinks, Junctions Symbolic Links and Mount Points, which are sparsley supported by standard tools. This tool is kind of a NTFS Swiss Army Knife and can do lots of things, like create SmartCopies, which preserve the inner and outer Hardlink/Junction/SymbolicLink structure, does hardlink based incremental Backups and a lot of other things which can not be found anywhere.
Das bedeutet übrigens nicht, dass man damit Windows sichern kann.

Es gibt übrigens ein RoboCopy GUI (ich halte von solchen Frontends nichts)
 
Zuletzt bearbeitet:
Vorab: Unten habe ich die beiden inline-Hilfen von robocopy und ln.exe eingefügt. Inbes. die von ln.exe ist wesentlich besser, als die vollkommen überladene Beschreibung auf der Webseite.

Ich habe gestern Windows 11 22H2 auf einer zusätzlichen 120 GB SSD standardmäßig im BIOS-Modus installiert, um es daran zu testen. - Noch nicht mit Schattenkopie, da es mir erst mal darum ging, die Tools kennenzulernen. - Wenig überraschend haben beide KIs (Google und Opera) teilweise Blödsinn erzählt…

Die Windows-Partition habe ich auf 40960 MiB verkleinert und eine BackUp-Partition (U: ;)) erstellt.

Zum installierten Windows:

Windows selbst lügt natürlich beim belegten Speicher:

1a-Win11-Lw.png

Aber ein Partitionierungstool vom Hirens PE-Win zeigt sie korrekt an:

1b-AOMEI.png

Wie auch GParted:

1c-GParted.png

Der Explorer zeigt wieder etwas anderes an, aber das liegt schon daran, dass er Hardlinks nicht als solche erkennt und so verlinkte Dateien mehrfach zählt (das machen auch Dateimanager unter Linux):

2a-Win11.png

Bei der Sicherung mit Robocopy (als Admin, aber nicht mit Schattenkopie) konnte vieles nicht nur nicht kopiert werden, sondern es fehlten auch "Programme" und "Dokumente und Einstellungen":

2b-Robocopy.png

Den Verusacher konnte ich als "/XJ" ermittelt (das war also falsch von der KI) und stattdessen erschien mit "/SJ" sinnvoll:

robocopy C:\ U:\Backup\1\ /MIR /COPYALL /DCOPY:DAT /SJ /SL /MT /R:0 /W:0 /LOG:U:\Backup\log.txt

Die gekürzten Logs (nur Anfang und Ende: die waren jeweils fast 40 MB groß) habe ich angehängt.

Wie gesagt: Ich will die Tools erst mal kennenlernen: Ich habe natürlich nicht vor, so eine "Sicherung" wiederherzustellen!


ln.exe hatte unter diesen Umständen viel weniger Probleme, wobei "--delorean" Quatsch war.

Für eine Sicherung braucht es "-b" (backup = inkl. Attribute) und "-c" (copy) oder "-o" (mirror - Vorsicht: "-m" ist move: die Quelle würde gelöscht!), die beide im Ergebnis fast identisch sind (erst "-c" dann "-o"):

2c-ln-c.png


2d-ln-o.png

Der Unterschied ist, dass copy nur neues und aktualisiertes dazu kopieren, während mirror aus der Quelle gelöschtes auch aus dem Ziel löscht.

Die Ausgabe zuletzt:
Code:
Copying...     100%, Items        135.212, Time elapsed:      00:06:33

              Total    Copied    Linked   Skipped  Excluded    Failed
  Folder:    26.434    26.434         -         0         0         0
    File:   108.705    74.114    34.194         0         0       397
Junction:        52         -        52         0         0         0
RparsUkn:        20         -         0         0         0        20
 Symlink:         1         -         1         0         0         0
    Byte:  16.384 m   8.192 m   6.144 m         0         0     513 m

                      Overall
   Times:        00:06:38.743


Das Linux "du" erkennt Hardlinks (s. o.) und zeigt die tatsächliche Belegung an:
Code:
Windows:
108.637 Dateien, 26.426 Ordner
10.129.378.777 Bytes (9,43 GiB)

robocopy:
28.012 Dateien, 26.397 Ordner
8.915.666.171 Bytes (8,30 GiB)

ln -c:
108.249 Dateien, 26.427 Ordner
9.617.192.182 Bytes (8,96 GiB)

ln -o:
108.246 Dateien, 26.426 Ordner
9.618.209.111 Bytes (8,96 GiB)

So weit der aktuelle Stand.


Code:
-------------------------------------------------------------------------------
   ROBOCOPY     ::     Robustes Dateikopieren für Windows
-------------------------------------------------------------------------------

  Gestartet: Sonntag, 27. September 2026 10:02:05
             Syntax :: ROBOCOPY Quelle Ziel [Datei [Datei]...] [Optionen]

             Quelle :: Quellverzeichnis (Laufwerk:\Pfad oder
                       \\Server\Freigabe\Pfad)
               Ziel :: Zielverzeichnis (Laufwerk:\Pfad oder
                       \\Server\Freigabe\Pfad)
              Datei :: Zu kopierende Dateien (Namen/Platzhalter: Standard
                       ist "*.*")

::
:: Kopieroptionen:
::
                 /S :: Kopiert Unterverzeichnisse, jedoch keine leeren
                       Unterverzeichnisse.
                 /E :: Kopiert Unterverzeichnisse, einschließlich leerer
                       Unterverzeichnisse.
             /LEV:n :: Kopiert nur die obersten Ebenen der
                       Quellverzeichnisstruktur.

                 /Z :: Kopiert Dateien im Neustartmodus.
                 /B :: Kopiert Dateien im Sicherungsmodus.
                /ZB :: Verwendet den Neustartmodus. Im Fall einer
                       Zugriffsverweigerung wird der Sicherungsmodus verwendet.
                 /J :: kopieren mit ungepuffertem E/A (empfohlen für sehr große
                       Dateien).
            /EFSRAW :: Kopiert alle verschlüsselten Dateien im EFS RAW-Modus.

    /COPY:copyflags :: Gibt an, welche Inhalte für Dateien kopiert werden
                       sollen (der Standard ist "/COPY:DAT").
                       (copyflags : D=Daten, A=Attribute, T=Zeitstempel, X=Alternative Datenströme überspringen (X wird ignoriert, wenn /B oder /ZB).
                       (S=Sicherheit=NTFS-ACLs, O=Besitzerinformationen,
                       U=Überwachungsinformationen).


               /SEC :: Kopiert Dateien mit Sicherheitsinformationen
                       (entspricht "/COPY:DATS").
           /COPYALL :: Kopiert alle Dateiinformationen
                       (entspricht "/COPY:DATSOU").
            /NOCOPY :: Kopiert keine Dateiinformationen
                       (hilfreich in Verbindung mit "/PURGE").
            /SECFIX :: Korrigiert die Dateisicherheit in allen Dateien, auch
                       in ausgelassenen Dateien.
            /TIMFIX :: Korrigiert die Uhrzeitangaben für Dateien in allen
                       Dateien, auch in ausgelassenen Dateien.

             /PURGE :: Löscht Zieldateien/-verzeichnisse, die in der Quelle
                       nicht mehr vorhanden sind.
               /MIR :: Spiegelt eine Verzeichnisstruktur
                       (Entspricht "/E" mit "/PURGE").

               /MOV :: Verschiebt Dateien
                       (löscht Dateien nach dem Kopieren an der Quelle).
              /MOVE :: Verschiebt Dateien UND Verzeichnisse
                       (löscht sie nach dem Kopieren an der Quelle).

     /A+:[RASHCNET] :: Fügt die vorhandenen Attribute den kopierten Dateien
                       hinzu.
     /A-:[RASHCNETO]:: Entfernt die vorhandenen Attribute aus kopierten Dateien.

            /CREATE :: Erstellt eine Verzeichnisstruktur und nur Dateien mit
                       einer Länge von Null.
               /FAT :: Erstellt Zieldateien nur unter Verwendung von
                       8.3 FAT-Dateinamen.
               /256 :: Deaktiviert die Unterstützung für sehr lange Pfade
                       (> 256 Zeichen).

             /MON:n :: Überwacht die Quelle. Wird erneut ausgeführt, wenn mehr
                       als n Änderungen gefunden werden.
             /MOT:m :: Überwacht die Quelle. Wird bei einer Änderung erneut
                       ausgeführt in m Minuten.

      /RH:hhmm-hhmm :: Ausführungsstunden - Steuert, wann neue Kopiervorgänge
                       gestartet werden können.
                /PF :: Überprüft die Ausführungsstunden pro Datei
                       (nicht pro Durchgang).

             /IPG:n :: Abstand zwischen Paketen (ms), um bei langsamen
                       Verbindungen Bandbreite freizugeben.

                /SJ :: Kopiert Verbindungen als Verbindungen anstatt als Verbindungsziele.
                /SL :: Kopiert symbolische Verknüpfungen als Verknüpfungen anstatt als Verknüpfungsziele.

            /MT[:n] :: Multithreadkopien mit n Threads erstellen (Standardwert: "8").
                       n muss zwischen 1 und 128 (einschließlich) liegen.
                       Die Option ist nicht mit "/IPG" und "/EFSRAW" kompatibel.
                       Die Ausgabe kann mit "/LOG" umgeleitet werden, um eine bessere Leistung zu erzielen.

/DCOPY:Kopierflag[s] :: zu kopierende Elemente für Verzeichnisse (Standard: "/DCOPY:DA").
                       (Kopierflags : D=Daten, A=Attribute, T=Zeitstempel, E=EAs, X=Alternative Datenströme überspringen).

           /NODCOPY :: kopiert keine Verzeichnisinformationen
                       (standardmäßig wird "/DCOPY:DA" ausgeführt).

         /NOOFFLOAD :: Dateien werden ohne den Windows-Kopieabladungs-
                       mechanismus kopiert.

          /COMPRESS :: Fordert während der Dateiübertragung ggf. Netzwerkkomprimierung an.

            /SPARSE :: Beibehalten des Sparse-Zustands während des Kopierens aktivieren
::
:: Einschränkungsoptionen für Dateikopien:
::
  /IoMaxSize:n[KMG] :: Angeforderte maximale E/A-Größe pro {read,write}-Zyklus, in n [KMG] Byte.

     /IoRate:n[KMG] :: Angeforderte E/A-Rate in n [KMG] Byte pro Sekunde.

  /Threshold:n [KMG] :: Dateigrößenschwellenwert für die Einschränkung in n [KMG] Byte (siehe Hinweise).

::
:: Dateiauswahloptionen:
::
                 /A :: Kopiert nur Dateien mit dem "Archive"-Attribut.
                 /M :: Kopiert nur Dateien mit dem "Archive"-Attribut und setzt
                       das Attribut zurück.
     /IA:[RASHCNETO]:: Schließt nur Dateien ein, bei denen eines der Attribute
                       festgelegt ist.
     /XA:[RASHCNETO]:: Schließt Dateien aus, bei denen eines der Attribute
                       festgelegt ist.

    /XF Datei[Datei]:: Schließt Dateien aus, die mit den angegebenen
                       Namen/Pfaden/Platzhaltern übereinstimmen.
    /XD Verz.[Verz.]:: Schließt Verzeichnisse aus, die mit den angegebenen
                       Namen/Pfaden übereinstimmen.

                /XC :: Schließt geänderte Dateien aus.
                /XN :: Schließt neuere Dateien aus.
                /XO :: Schließt ältere Dateien aus.
                /XX :: Schließt zusätzliche Dateien und Verzeichnisse aus.
                /XL :: Schließt einsame Dateien und Verzeichnisse aus.
                /IS :: Schließt identische Dateien ein.
                /IT :: Schließt optimierte Dateien ein.

             /MAX:n :: Maximale Dateigröße - schließt Dateien aus, die größer
                       als n Bytes sind.
             /MIN:n :: Minimale Dateigröße - schließt Dateien aus, die kleiner
                       als n Bytes sind.

          /MAXAGE:n :: Maximales Dateialter - schließt Dateien aus, die älter
                       als n Tage/Datum sind.
          /MINAGE:n :: Minimales Dateialter - schließt Dateien aus, die neuer
                       als n Tage/Datum sind.
          /MAXLAD:n :: Maximales Datum des letztes Zugriffs - schließt Dateien
                       aus, die seit n nicht verwendet wurden.
          /MINLAD:n :: Minimales Datum des letztes Zugriffs - schließt Dateien
                       aus, die seit n verwendet wurden.
                       (Wenn n < 1900, dann ist n = n Tage, andernfalls ist
                       n = Datum im Format JJJJMMTT).

               /FFT :: Geht von FAT-Uhrzeitangaben für Dateien aus (Granularität von zwei Sekunden).
               /DST :: Kompensiert Zeitunterschiede von einer Stunde aufgrund
                       der Sommerzeit.

                /XJ :: Schließt Links (für Dateien und Verzeichnisse) und Verbindungspunkte aus.
               /XJD :: Schließt symbolische Verknüpfungen für Verzeichnisse und Verknüpfungspunkte aus.
               /XJF :: Schließt symbolische Verknüpfungen für Dateien aus.

                /IM:: Enthält geänderte Dateien (abweichende Änderungszeiten).
::
:: Wiederholungsoptionen:
::
               /R:n :: Anzahl von Wiederholungsversuchen bei fehlerhaften
                       Kopiervorgängen. Der Standardwert ist 1 Million.
               /W:n :: Wartezeit zwischen Wiederholungsversuchen.
                       Der Standardwert ist 30 Sekunden.

               /REG :: Speichert "/R:n" und "/W:n" in der Registrierung als
                       Standardeinstellungen.

               /TBD :: Wartet, dass Freigabenamen definiert werden (Wiederholungsfehler 67).

               /LFSM :: Betrieb im Modus "wenig freier Speicherplatz", ermöglicht Kopieren, Anhalten und Fortsetzen (siehe Anmerkungen).

        /LFSM:n[KMG] :: /LFSM, gibt die Floor-Größe in [K:Kilo,M:Mega,G:Giga] Byte an.

::
:: Protokollierungsoptionen :
::
                 /L :: Listet nur auf. Es werden keine Kopiervorgänge
                       ausgeführt, Zeitstempel erstellt oder Dateien gelöscht.
                 /X :: Meldet alle zusätzlichen Dateien, nicht nur die
                       ausgewählten Dateien.
                 /V :: Erstellt eine ausführliche Ausgabe mit ausgelassenen
                       Dateien.
                /TS :: Schließt Zeitstempel von Quelldateien in die Ausgabe ein.
                /FP :: Schließt den vollständigen Pfadnamen von Dateien in
                       die Ausgabe ein.
             /BYTES :: Gibt Größen in Bytes aus.

                /NS :: Keine Größe - Dateigrößen werden nicht protokolliert.
                /NC :: Keine Klasse - Dateiklassen werden nicht protokolliert.
               /NFL :: Keine Dateiliste - Dateinamen werden nicht protokolliert.
               /NDL :: Keine Verzeichnisliste - Verzeichnisnamen werden nicht
                       protokolliert.

                /NP :: Kein Status - der Prozentsatz kopierter Elemente wird
                       nicht angezeigt.
               /ETA :: Zeigt die ungefähre Empfangszeit der kopierten Dateien
                       an.

         /LOG:Datei :: Gibt den Status der Protokolldatei aus (überschreibt das
                       vorhandene Protokoll).
        /LOG+:Datei :: Gibt den Status der Protokolldatei aus
                       (wird an das vorhandene Protokoll angefügt).

      /UNILOG:Datei :: Gibt den Status der Protokolldatei als UNICODE aus
                       (überschreibt das vorhandene Protokoll).
     /UNILOG+:Datei :: Gibt den Status der Protokolldatei als UNICODE aus
                       (wird an das vorhandene Protokoll angefügt).

               /TEE :: Gibt Daten in das Konsolenfenster und die Protokolldatei
                       aus.

               /NJH :: Kein Auftragsheader.
               /NJS :: Keine Auftragszusammenfassung.

           /UNICODE :: Gibt den Status als UNICODE aus.

::
:: Auftragsoptionen:
::
  /JOB:Auftragsname :: Übernimmt Parameter aus der angegebenen Auftragsdatei.
 /SAVE:Auftragsname :: Speichert Parameter in der angegebenen Auftragsdatei.
              /QUIT :: Beendet den Vorgang nach der Verarbeitung
                       der Befehlszeile (zum Anzeigen von Parametern).
              /NOSD :: Es ist kein Quellverzeichnis angegeben.
              /NODD :: Es ist kein Zielverzeichnis angegeben.
                /IF :: Schließt die folgenden Dateien ein.

::
:: Hinweise:
::
       Bei der Verwendung von /PURGE oder /MIR im Stammverzeichnis des Volumes
       wurde der angeforderte Vorgang von Robocopy zuvor auch auf Dateien innerhalb
       des Verzeichnisses mit Systemvolumeinformationen angewendet.
       Dies ist nicht länger der Fall. Falls angegeben, überspringt Robocopy Dateien
       oder Verzeichnisse mit diesem Namen im obersten Quell- und Zielverzeichnis des Kopiervorgangs.

       Die geänderte Dateiklassifizierung gilt nur, wenn sowohl die Quell-
       als auch die Zieldateisysteme Änderungszeitstempel unterstützen (z. B. NTFS)
       und die Quell-und Zieldateien unterschiedliche Änderungszeiten aufweisen, ansonsten jedoch
       identisch sind. Diese Dateien werden nicht standardmäßig kopiert. Geben Sie /IM an,
       um sie einzubeziehen.

       Das /DCOPY:E-Flag erfordert, dass das Kopieren erweiterter Attribute
       für Verzeichnisse versucht werden sollte. Beachten Sie, dass robocopy derzeit fortgesetzt wird,
       wenn die EAs eines Verzeichnisses nicht kopiert werden können. Dieses Flag ist auch nicht
       in /COPYALL.

       Wenn entweder /IoMaxSize oder /IoRate angegeben wird, aktiviert Robocopy
       Einschränkung von Dateikopien (zur Verringerung der Systemauslastung).
       Beide können auf zulässige oder optimale Werte angepasst werden. d. h. beide
       die gewünschten Kopierparameter angeben, aber das System und Robocopy sind
       zulässig, sie bei Bedarf auf vernünftige/zulässige Werte anzupassen.
       Wenn /Threshold ebenfalls verwendet wird, gibt es eine minimale Dateigröße für
       Einschränkung aktiviert; Dateien unterhalb dieser Größe werden nicht eingeschränkt.
       Den Werten für alle drei Parameter kann ein optionales Suffix folgen
       Zeichen aus dem Satz [KMG] (Kilo, Mega, Giga).

       Verwendet /LFSM-Anforderungen für robocopy, um im Modus „wenig freier Speicherplatz” zu arbeiten.
       In diesem Modus wird Robocopy angehalten, wenn eine Dateikopie dazu führt,
       dass freier Speicherplatzes auf dem Ziel-Volume unter einen "Floor"-Wert sinkt, der
       explizit durch die LFSM:n[KMG]-Form des Flags angegeben werden kann.
       Wenn /LFSM ohne expliziten Floor-Wert angegeben ist, wird dieser auf
       zehn Prozent der Größe des Zielvolumens.
       Der Modus „wenig freier Speicherplatz“ ist nicht kompatibel mit /MT und /EFSRAW.

Code:
ln 2.934 (Recursively) creates hardlinks for files within NTFS partitions
Usage. ln [options] [commands] file|dir|UNCname [name|dir|UNCname [dir]]

Commands
      --anchor PATH
  -c, --copy SRCPATH DESTPATH
      --deeppathdelete SRCPATH        Delete path longer than 256 characters
  -d, --delorean SRCPATH BACKUPPATH_0 BACKUPPATH_1
  -e, --enum SRCPATH                  Enumerate corresponding files
  -x, --exclude WILDCARD              Exclude file <wildcard>
  -X, --excludedir WILDCARD           Exclude directory Recursively <wildcard>
  -p, --excluderegexp REGEXP          Exclude file <reg expr filename>
  -P, --excluderegexpdir REGEXP       Exclude directory <reg expr directory>
      --include WILDCARD              Include files <wildcard>
      --includedir WILDCARD           Include directory Recursively <wildcard>
      --includeregexp REGEXP          Include file <reg expr filename>
      --includeregexpdir REGEXP       Include directory <reg expr directory>
  -j, --junction JUNCTION [TARGETDIR] Show/Create a junction
  -l, --list FILENAME                 List hardlink siblings
  -o, --mirror SRCPATH DESTPATH
  -m, --move SRCPATH DESTPATH
      --output FILENAME               Redirect output to FILENAME
      --probefs PATH                  Show type of filesystem
  -r, --recursive SRCPATH DESTPATH    Create a clone
      --source SRCPATH                Specify additional source directories
  -i, --splice [WILDCARD]             Splice Junctions/Symlink dirs <wildcard>
  -s, --symbolic SYMBOLICLINK         Show symbolic link target
      --timetolerance MILLISECONDS    File comparison tolerance <miliseconds>
      --truesize SRCPATH              Used space taking into account hardlinks
  -u, --unroll [WILDCARD]             Unroll Junctions/Symlink dirs <wildcard>

Options
  -b, --backup                        Backup mode copies also ACLs
  -a, --absolute                      Force symbolic links target to absolute
      --dupemerge                     Use Dupemerge' hashing to find hardlinks
  -h, --help                          This help
      --json                          Prints the output in json format
      --keepsymlinkrelation           Save absolute/relative state of symlinks
      --noea                          Do not copy EA Records
      --noads                         Do not copy Alternative Data Streams (ADS)
      --progress                      Show a progress indicator on the console
  -q, --quiet                         Operation with no output
      --skipfiles                     Don't operate on files, but only on dirs
  -s, --symbolic                      Create symbolic link
      --traditional                   Use compatibility mode for remote drives
      --1023safe                      Workaround the 1023 hardlink limit

Samples
  ln sourcefile.txt destination.txt
  ln --recursive x:\dir\dir2 x:\dir\newdir
  ln --recursive x:\dir\dir2 x:\anotherdir
  ln \\local_computer\sourcefile.txt x:\dir_on_local_computer\destination.txt
  ln \\local_computer\sourcefile.txt \\local_computer\destination.txt
  ln --recursive \\local_computer\sourcedir x:\dir\dir2
  ln --recursive \\local_computer\sourcedir \\local_computer\destdir\sample
  ln --enum x:\dir\dir2
  ln --copy x:\source\dir2 x:\dest\dir2
  ln --source x:\src\loc1 --copy x:\source\dir2 x:\dest\dir2
  ln --junction x:\source\junction x:\dest\junction target
  ln --junction x:\source\junction
  ln --symbolic sourcefile.txt destination.txt
  ln --list sourcefile.txt
 

Anhänge

Zuletzt bearbeitet:
Jetzt vom PE-Windows (so sollte es auch mit der Schattenkopie funktionieren) und auf der ln-Homepage habe ich entdeckt, wofür Mcfly ist:
A real word example looks like this:

ln --copy x:\dir\Source x:\dir\InitialBackup
This creates the initial Backup as shown above in Phase 1

ln --delorean x:\dir\Source x:\dir\InitialBackup x:\dir\Backup1
This command does the first round of DeLorean copy as shown above in Phase 2 and Phase 3 creating a backup.

ln --delorean x:\dir\Source x:\dir\Backup1 x:\dir\Backup2
This command creates another set of incremental DeLorean copy as shown above in Phase 2 and Phase 3 creating another backup.

Also zuerst die initiale Sicherung (Windows hatte ich inzwischen etwas ausgemistet):
Code:
ln.exe -bq --progress -c C:\ U:\Backup\ln-c\

Copying...     100%, Items        134,161, Time elapsed:      00:02:33

              Total    Copied    Linked   Skipped  Excluded    Failed
  Folder:    26,109    26,109         -         0         0         0
    File:   107,979    73,785    34,194         0         0         0
Junction:        52         -        52         0         0         0
RparsUkn:        20         -         0         0         0        20
 Symlink:         1         -         1         0         0         0
    Byte:  16,384 m   9,216 m   6,144 m         0         0         0

                      Overall
   Times:        00:02:40.594
Dann die nächste Sicherungsstufe, bei der (wie bei meiner Linux-Sicherung) unverändertes als Hardlinks übernommen wird:
Code:
ln.exe -bq --progress -d C:\ U:\Backup\ln-c\ U:\Backup\ln-d\

Cloning  ...  100%, Items        134,140, Time elapsed:      00:00:31
Mirroring...  100%, Items        134,161, Time elapsed:      00:00:00

              Total    Copied    Linked   Skipped   Removed  Excluded    Failed
  Folder:    26,109         0         -    26,109         0         0         0
    File:   107,979         0         0   107,979         0         0         0
Junction:        52         -         0        52         0         0         0
RparsUkn:        20         -         0         0         0         0        20
 Symlink:         1         -         0         1         0         0         0
    Byte:  16,384 m         0         0  16,384 m         0         0         0

                      Overall               Clone              Mirror
   Times:        00:00:35.156        00:00:33.718        00:00:01.438
Da ich das direkt nacheinander gemacht habe, gab es natürlich keine Änderungen.

Anschließend robocopy C:\ U:\Backup\rc-xj+sj+sl\ /MIR /COPYALL /DCOPY:DAT /XJ /SJ /SL /MT /R:0 /W:0 /LOG:U:\Backup\rc-xj+sj+sl.txt, was fast doppelt so lange gebraucht hat und verlinktes offenbar mehrfach kopiert hat, obwohl ich das mit "/XJ /SJ /SL" ausgeschlossen hatte:
Code:
               Total    Copied   Skipped  Mismatch    FAILED    Extras
    Dirs :     26161     26107        54         0         0         0
   Files :    107992    107992         0         0         0         0
   Bytes :  16.214 g  16.214 g         0         0         0         0
   Times :   0:36:31   0:03:57                       0:00:00   0:00:33


   Speed :           73,175,346 Bytes/sec.
   Speed :            4,187.127 MegaBytes/min.
   Ended : Sunday, September 27, 2026 3:06:58 PM
Dann nochmal das, was die KI vorgeschlagen hatte: robocopy C:\ U:\Backup\rc-xj+sl\ /MIR /COPYALL /DCOPY:DAT /XJ /SL /MT /R:0 /W:0 /LOG:U:\Backup\rc-xj+sl.txt - Auch nicht besser.
Code:
               Total    Copied   Skipped  Mismatch    FAILED    Extras
    Dirs :     26161     26107        54         0         0         0
   Files :    107992    107992         0         0         0         0
   Bytes :  16.214 g  16.214 g         0         0         0         0
   Times :   0:57:17   0:06:03                       0:00:00   0:00:49


   Speed :           47,892,421 Bytes/sec.
   Speed :            2,740.426 MegaBytes/min.
   Ended : Sunday, September 27, 2026 3:15:44 PM
Nur "/SJ /SL" hatte bei einem vorherigen Test das gleiche ergeben.

Also Robocopy kann man dafür vergessen: Ehemals Teil der "Powertoys" (unter Power stelle ich mir was anderes vor) und schon seit vielen Jahren (auch schon bei Windows 10) direkter Bestandteil von Windows.

Hier die tatsächlichen Größem:
Code:
Windows:
9.964.117.962 Bytes

ln-c:
9.964.118.598 Bytes

ln-d:
9.964.118.598 Bytes

ln-* (die Differenz c->d alles andere sind Hardlinks):
9.964.118.598 Bytes
        3.028 Bytes

rc-xj+sj+sl:
17.409.805.213 Bytes

rc-xj+sl:
17.409.805.213 Bytes
Wenn ich das Robocopy-"Backup" wiederherstellen würde, würe Windows auch so groß: Es würde vielleicht noch booten, aber wer weiß, wie es sich auf dauer verhält.
 
Diesmal versuche ich McFly schrittweise nachzuahmen.
(wieder vom PE-Win aus - interessant übrigens, dass es die beim installierten Windows vergebenen Laufwerksbuchstaben übernommen hat)

Zuerst die letzte Sicherungsstufe per recursive clonen und dann per mirror von C:\ aktualisieren:
Code:
ln.exe -bq --progress -r U:\Backup\ln-d\ U:\Backup\ln-r\

Cloning...     100%, Items        134,140, Time elapsed:      00:00:42

              Total    Copied    Linked   Skipped  Excluded    Failed
  Folder:    26,109    26,109         -         0         0         0
    File:   107,979         0   107,979         0         0         0
Junction:        52         -        52         0         0         0
 Symlink:         1         -         1         0         0         0
    Byte:  16,384 m         0  16,384 m         0         0         0

                      Overall
   Times:        00:00:46.906

ln.exe -bq --progress -o C:\ U:\Backup\ln-r\

Mirroring...  100%, Items        134,265, Time elapsed:      00:00:03

              Total    Copied    Linked   Skipped   Removed  Excluded    Failed
  Folder:    26,138       147         -    25,991       118         0         0
    File:   108,054       678         2   107,374       244         0         0
Junction:        52         -         0        52         0         0         0
RparsUkn:        20         -         0         0         0         0        20
 Symlink:         1         -         0         1         0         0         0
    Byte:  16,384 m     388 m   102,652  15,360 m     261 m         0         0

                      Overall
   Times:        00:00:09.750
Das sieht erst mal gut aus. Offenbar scheint delorean tatsächlich so zu funktionieren.

Und nun der Hardcore-Test :)

C:\ vollständig formatieren und dann wiederherstellen:

C-Formatierung-1.png
C-Formatierung-2.png

Code:
ln.exe -bq --progress -c U:\Backup\ln-r\ C:\

Copying...     100%, Items        134,245, Time elapsed:      00:01:58

              Total    Copied    Linked   Skipped  Excluded    Failed
  Folder:    26,138    26,136         -         1         0         3
    File:   108,054    73,866    34,188         0         0         0
Junction:        52         -        52         0         0         0
 Symlink:         1         -         1         0         0         0
    Byte:  16,384 m   9,216 m   6,144 m         0         0         0

                      Overall
   Times:        00:02:00.125
Ich bin gespannt (hoffe das beste und erwarte das schlimmste ;)).

…

Tja, was nun?

Das formatierte und wiederhergestellte Windows 11 (Pro) bootet anstandslos und ohne jede Auffälligkeiten:

C-Formatierung-3.png



So viel zu "geht nicht" …​
 
Auch wenn ich kein Windows 11 mag, finde ich das wunderbar!
Wie hoch ist der Aufwand ggü. einer Sicherung in eins der VM-Formate (R-DriveImage bietet dies z.B.)?
2 Stunden find ich schon ganz schön lange.
 
Tanzmusikus schrieb:
Wie hoch ist der Aufwand ggü. einer Sicherung in eins der VM-Formate (R-DriveImage bietet dies z.B.)?
Das sagt mir nichts.

Aktueller Stand bei dieser Sicherung ist:
  1. Hirens PE-Windows booten
  2. ln.exe in system32 kopieren (da ist es im Pfad)
  3. DOS-Fenster als Administrator öffnen
  4. Sicherung wie beschrieben (nur mit den entsprechenden Laufwerksbuchstaben und Pfaden) durchführen
Die erste Sicherung dauert so lange wie es dauert alle Daten zu kopieren (s. o.), bei weiteren Sicherungen werden nur noch die Änderungen übertragen, was je Menge eben entsprechend schneller ist.

Als nächstes werde ich mich mit der Schattenkopie beschäftigen (damit habe ich noch nie etwas gemacht), damit die Sicherung auch aus dem laufenden System heraus funktioniert.
 
Tanzmusikus schrieb:
R-DriveImage ist superschnell & auch kompfortabel.
Für Windows-Version für Windows leider nicht kostenlos.
Das ist genau das Gegenteil von dem was ich hier mache:
R-Drive Image ist ein leistungsfähiges Dienstprogramm zur Erstellung von Disc-Abbildern für weitere Sicherungs- oder Duplizierungszwecke. Eine Disc-Abbilddatei enthält eine exakte Byte-zu-Byte-Kopie …
…
Mit R-Drive Image können Sie Ihr System nach einem schweren Datenverlust wegen eines Betriebssystemabsturzes, Virusangriffs oder Hardware-Fehlers komplett und schnell wiederherstellen.
Das ist sozusagen die primitivste Version eines Backups überhaupt: Besser als gar nichts, aber nicht empfehlenswert und keine Alternative zu ln.exe

Es überschreibt das vollständige Laufwerk (schlecht für SSDs), anstatt nur die Änderungen wieder zurückzusetzt. - Lies bitte meine Beiträge hier. Das hatte ich schon beschrieben.

R-Drive Image hat in diesem Thread nichts verloren.
 
Zuletzt bearbeitet:
Caramon2 schrieb:
Es überschreibt das vollständige Laufwerk (schlecht für SSDs), anstatt nur die Änderungen wieder zurückzusetzen.
Verstehe. Das wusste ich nicht.



Dann sind das -> Minuten statt Stunden?
Code:
                Overall
   Times:        00:02:00.125
 
Tanzmusikus schrieb:
Dann sind das -> Minuten statt Stunden?
Code:
                Overall
   Times:        00:02:00.125
Natürlich!

0 Stunden, 2 Minuten und 0,125 Sekunden

Und es hat nur deshalb so lange gedauert, weil ich die Partition formatiert hatte und alles geschrieben werden musste.

Im Normalfall muss nicht formatiert werden, so das nur die Änderungen seit der Sicherung zurück gesetzt werden, wie bei der vorher gemachten zweiten Sicherung:

1. Sicherung (alles muss geschrieben werden): 00:02:40.594

ab 2. Sicherung (nur noch die Änderungen): 00:00:35.156

Wobei 1. ein frisch installiertes Windows 11 ist und es bei 2. keine Änderungen gab: Einzig das kopieren der ganzen Verzeichnisstruktur hat so lange gedauert.

Bei einem gut ausgestatteten Produktivsystem dauert 1. natürlich länger, weil viel mehr gesichert werden muss und ab 2. hängt es eben davon ab, wie viel sich seit der letzten Sicherung geändert hat. - Also je häufiger man sichert, um so weniger Änderungen müssen gesichert werden, um so schneller ist es.

Wie bei meiner Linux-Sicherung mit rsync: Selbst wenn es sehr viele Aktualisierungen gab (z. B. beide Kernel (Mainline und LTS) und die Firmwarepakete), dauert eine Sicherung des ganzen Systems (mit SATA-SSDs und meinem alten AMD FX-8350) nur 30-40 Sek., weil das meiste aus der vorherigen Sicherung als Hardlinks übernommen werden kann: Bilder, Videos, Musik, usw.

Btw:

Ich dachte die 2h hätten sich auf R-Drive bezogen und habe mich gefragt, was daran schnell sein soll: Wenn das komplette Laufwerk kopiert und vor allem später wieder geschrieben wird (also weil über den SLC-Cache hinaus), kann es ja wirklich so lange dauern.
 
Zuletzt bearbeitet:
Caramon2 schrieb:
Nochmal:

Ich möchte eine vollständige Windows-Installation so effizient sichern und wiederherstellen können, wie es sich bei Linux-Installationen bei mir und im Bekanntenkreis schon seit 10 Jahren bewährt:
Ja - und Du hast mit Veeam for Linux eine Antwort erhalten.
Wo ist das Problem? Nutze es einfach.
 
mchawk777 schrieb:
Ja - und Du hast mit Veeam for Linux eine Antwort erhalten.
Wo ist das Problem? Nutze es einfach.
Kannst du nicht mal lesen was du selbst gequotet hast? :freak:

Ich möchte für Windows eine Sicherung, die Windows in der Art sichert, wie ich es bei Linux schon lange mache. - Was gibt es daran nicht zu verstehen???

Oder hieran:
Caramon2 schrieb:
Wichtig: Linux ist hier kein Thema! Die verlinkte Sicherung dient nur als Referenz.

Lesen -> denken -> verstehen - Das kann doch nicht so schwierig sein…
 
Zuletzt bearbeitet: (Tippfehler)
Caramon2 schrieb:
Ich möchte für Windows eine Sicherung, die Windows in der Art sichert, wie ich es bei Linux schon lange mache. - Was gibt es daran nicht zu verstehen???
Bei aller Ehre für Deine Mühe und was Du da zum Laufen gebracht hast, es hat gravierende Nachteile, gestatte mir bitte die Kritik.
  1. Man sollte nicht seinen gewohnten Workflow aus einem OS an ein anderes OS übertragen
  2. Man sollte sich an das OS anpassen, nicht umgekehrt, daß OS an sich anpassen, wenn man dafür grob den Standard verläßt oder verändert
  3. Dreh- und Angelpunkt Deines Konzeptes bist Du mit Deinem Now-How, was den anderen, wenn Du mal weg bist oder nicht zugreifbar, nichts mehr nützen wird, weil es kaum einer versteht noch anwenden kann. Sprich, Deine Lösung ist keinesfalls nachhaltig, woan man bei Entwicklungen auch immer denken sollte
  4. Du hast was gegen proprietäre Software, und schließt sie kategorisch aus, egal wie gut oder leistungsfähig sie ist. Gute verbreitete Software bietet - im Gegensatz zu Deiner Insellösung - aber Herstellersupport, und entsprechende Unterstützung im Netz durch den Grad der Bekanntheit und anderer Anwender. Bei Deiner Insellösung sieht es dagegen mau aus
  5. Sorry, und Recovery einer Windowspartition bekommt heute jedes gute bekannte Backupprogramm einfacher und schneller hin. Rechne mal Deine Aufwand mit Zeit und entsprechendem Stundenlohn in Geld um, da hätte sich jedes lummige kostenpflichtige Backupprogramm schon lange amortisiert. Von den kostenlosen verfügbaren Programmen mal ganz zu schweigen
Wie gesagt, Respekt dafür, daß Du es auf Deine Weise lösen könntest, weil Du anscheinend genügend Zeit für sowas hast. Dagegen kauf ich eben ein Programm, daß bei mir und in meinem Bekanntenkreis prima funktioniert, wo auf Knopfdruck ebenso schnell das System wieder herstellt ist, ohne diese Umstände. Und sie brauchen mich danach nicht weiter mehr, da sie sich an den Hersteller und das Netz wenden können. Lebenzeit für mich für sinnvollere Dinge gespart.
 
  • Gefällt mir
Reaktionen: Caramon2
Oktober 2026
Zurück
Oben